@@ -62,7 +62,11 @@ public:
     // Some DMD Declarations don't have the loc set, this searches decl's parents
     // until a valid loc is found.
     static void setDeclLoc(tree t, Dsymbol * decl);
-
+    
+#if D_GCC_VER >= 40
+    static void setCfunEndLoc(const Loc & loc);
+#endif
+    
     static void giveDeclUniqueName(tree decl, const char * prefix = NULL);
 public:
     // Set a DECL's STATIC and EXTERN based on the decl's storage class
