@@ -347,7 +347,7 @@ void ArrayInitializer::addInit(Expression *index, Initializer *value)
 Initializer *ArrayInitializer::semantic(Scope *sc, Type *t)
 {   unsigned i;
     unsigned length;
-    const unsigned long amax = 0x80000000;
+    const unsigned amax = 0x80000000;
 
     //printf("ArrayInitializer::semantic(%s)\n", t->toChars());
     if (sem)                            // if semantic() already run
@@ -400,7 +400,7 @@ Initializer *ArrayInitializer::semantic(Scope *sc, Type *t)
     }
 
     if ((unsigned long) dim * t->nextOf()->size() >= amax)
-    {   error(loc, "array dimension %"PRIuTSIZE" exceeds max of %"PRIuMAX, dim, amax / t->nextOf()->size());
+    {   error(loc, "array dimension %"PRIuTSIZE" exceeds max of %"PRIuTSIZE, dim, amax / t->nextOf()->size());
         goto Lerr;
     }
     return this;
